---
title: <span class="badge builder"></span> ArcOption
---
# <span class="badge builder"></span> ArcOption

## Constructor

```python
ArcOption()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> nodegraph.ArcOption
```

### <span class="badge object-method"></span> color

The color of the arc.

```python
def color(color: str) -> typing.Self
```

### <span class="badge object-method"></span> field

Field from which to get the value. Values should be less than 1, representing fraction of a circle.

```python
def field(field: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ArcOption](./object-ArcOption.md)
